summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEric Yilun Lin <yllin@chromium.org>2022-12-20 10:04:21 +0800
committerChromeos LUCI <chromeos-scoped@luci-project-accounts.iam.gserviceaccount.com>2022-12-20 03:54:35 +0000
commit544db30e668539474096f36f2ebf2241fc6a49da (patch)
tree2d2e709f4c5b3ff126a2d9135c245b1500f26931
parent84ab332d934b703e4a4b302a11025525e6801602 (diff)
downloadchrome-ec-544db30e668539474096f36f2ebf2241fc6a49da.tar.gz
corsola: reduce the type-c port count init delay to 500ms
Following chromium:4114047, the fake type-c port count can be set within a shorter timing. The pd_task is spawned around 150ms ~ 180ms after boot, so 500 ms delay should be a safe delay to prevent a failure with a fast kernel upstart. BUG=b:262898170 TEST=reboot EC for 1600 times and no HDMI output errors BRANCH=none Change-Id: I533e316104bfb7c26695bf8c55ad977e59aeba56 Signed-off-by: Eric Yilun Lin <yllin@chromium.org> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/4113632 Auto-Submit: Eric Yilun Lin <yllin@google.com> Commit-Queue: Knox Chiou <knoxchiou@chromium.org> Tested-by: Eric Yilun Lin <yllin@google.com> Code-Coverage: Knox Chiou <knoxchiou@chromium.org> Reviewed-by: Sung-Chi Li <lschyi@chromium.org>
-rw-r--r--zephyr/program/corsola/src/usbc.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/zephyr/program/corsola/src/usbc.c b/zephyr/program/corsola/src/usbc.c
index a81bd0999b..518cceee07 100644
--- a/zephyr/program/corsola/src/usbc.c
+++ b/zephyr/program/corsola/src/usbc.c
@@ -215,11 +215,11 @@ static void baseboard_x_ec_gpio2_init(void)
* After C1 port tasks finished, we intentionally increase the port
* count by 1 for usb_mux to access the C1 virtual mux for notifying
* mainlink direction.
* The current delay is set to 1 second. cros-ec-typec module will
* not be getting the fake type-c port count if the deferred call is
* later than the kernel upstarts.
*/
- hook_call_deferred(&tasks_init_deferred_data, SECOND);
+ hook_call_deferred(&tasks_init_deferred_data, 500 * MSEC);
}
DECLARE_HOOK(HOOK_INIT, baseboard_x_ec_gpio2_init, HOOK_PRIO_DEFAULT);
@@ -215,11 +215,11 @@ static void baseboard_x_ec_gpio2_init(void)
* count by 1 for usb_mux to access the C1 virtual mux for notifying
* mainlink direction.
- * The current delay is set to 1 second. cros-ec-typec module will
+ * The current delay is set to 500 ms. cros-ec-typec module will
* not be getting the fake type-c port count if the deferred call is
* later than the kernel upstarts.